# Impact Effect Simulator Library

[![Python](https://img.shields.io/pypi/pyversions/tensorflow.svg?style=plastic)](https://badge.fury.io/py/tensorflow)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) 

> [English](../README.md) | 中文



## 🍞 Features
- features


##  🖥 Install

ImpactEffect has been released in PyPI, which means it can be installed by PIP directly.

```python
pip install impactEffect
```

##  🍕 develop



##  🚩 Usage
